@@ -5,9 +5,9 @@ from pyspark.sql.functions import coalesce, to_timestamp
 
 from spark_auto_mapper.data_types.column import AutoMapperDataTypeColumn
 from spark_auto_mapper.data_types.data_type_base import AutoMapperDataTypeBase
-from spark_auto_mapper.data_types.literal import AutoMapperDataTypeLiteral
 from spark_auto_mapper.helpers.value_parser import AutoMapperValueParser
 from spark_auto_mapper.type_definitions.defined_types import AutoMapperDateInputType
+from spark_auto_mapper.data_types.text_like_base import AutoMapperTextLikeBase
 
 
 class AutoMapperDateTimeDataType(AutoMapperDataTypeBase):
@@ -59,7 +59,7 @@ class AutoMapperDateTimeDataType(AutoMapperDataTypeBase):
             and not dict(source_df.dtypes)[self.value.value] == "timestamp"
         ):
             return coalesce(*formats_column_specs)
-        elif isinstance(self.value, AutoMapperDataTypeLiteral):
+        elif isinstance(self.value, AutoMapperTextLikeBase):
             return coalesce(*formats_column_specs)
         else:
             column_spec = self.value.get_column_spec(
