@@ -8,7 +8,6 @@ from pyspark.sql.functions import col
 from pyspark.sql.functions import to_date
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -43,8 +42,8 @@ def test_auto_mapper_date_column_typed(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["birthDate"], col("b.date_of_birth").alias("birthDate")
+    assert str(sql_expressions["birthDate"]) == str(
+        col("b.date_of_birth").alias("birthDate")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
