@@ -6,6 +6,7 @@ from tests.conftest import clean_spark_session
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
+
 # noinspection PyUnresolvedReferences
 
 
@@ -15,9 +16,7 @@ def test_automapper_field(spark_session: SparkSession) -> None:
 
     data_json_file: Path = data_dir.joinpath("data.json")
 
-    source_df: DataFrame = spark_session.read.json(
-        str(data_json_file), multiLine=True
-    )
+    source_df: DataFrame = spark_session.read.json(str(data_json_file), multiLine=True)
 
     source_df.createOrReplaceTempView("patients")
 
@@ -29,9 +28,7 @@ def test_automapper_field(spark_session: SparkSession) -> None:
     )
 
     assert isinstance(mapper, AutoMapper)
-    sql_expressions: Dict[str, Column] = mapper.get_column_specs(
-        source_df=source_df
-    )
+    sql_expressions: Dict[str, Column] = mapper.get_column_specs(source_df=source_df)
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
