@@ -1,12 +1,11 @@
 from typing import Dict
 
 from pyspark.sql import SparkSession, Column, DataFrame
-from pyspark.sql.functions import array
+from pyspark.sql.functions import array, when, coalesce
 from pyspark.sql.functions import lit, filter
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 
 
 def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
@@ -37,11 +36,14 @@ def test_auto_mapper_array_multiple_items(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["dst2"],
-        filter(array(lit("address1"), lit("address2")), lambda x: x.isNotNull()).alias(
-            "dst2"
-        ),
+    assert str(sql_expressions["dst2"]) == str(
+        when(
+            array(lit("address1"), lit("address2")).isNotNull(),
+            filter(
+                coalesce(array(lit("address1"), lit("address2")), array()),
+                lambda x: x.isNotNull(),
+            ),
+        ).alias("dst2")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
