@@ -1,11 +1,10 @@
 from typing import Dict
 
 from pyspark.sql import SparkSession, Column, DataFrame
-from pyspark.sql.functions import array, expr, filter
+from pyspark.sql.functions import array, expr, filter, when, coalesce
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
 from spark_auto_mapper.data_types.list import AutoMapperList
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 
 
 def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
@@ -36,9 +35,11 @@ def test_auto_mapper_array_single_item(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["dst2"],
-        filter(array(expr("address1")), lambda x: x.isNotNull()).alias("dst2"),
+    assert str(sql_expressions["dst2"]) == str(
+        when(
+            array(expr("address1")).isNotNull(),
+            filter(coalesce(array(expr("address1")), array()), lambda x: x.isNotNull()),
+        ).alias("dst2")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
