@@ -9,7 +9,6 @@ from pyspark.sql.functions import trim
 from pyspark.sql.functions import col
 
 from spark_auto_mapper.automappers.automapper import AutoMapper
-from spark_auto_mapper.expression_comparer import assert_expressions_are_equal
 from spark_auto_mapper.helpers.automapper_helpers import AutoMapperHelpers as A
 
 
@@ -38,8 +37,8 @@ def test_auto_mapper_trim(spark_session: SparkSession) -> None:
     for column_name, sql_expression in sql_expressions.items():
         print(f"{column_name}: {sql_expression}")
 
-    assert_expressions_are_equal(
-        sql_expressions["my_column"], trim(col("b.last_name")).alias("my_column")
+    assert str(sql_expressions["my_column"]) == str(
+        trim(col("b.last_name")).alias("my_column")
     )
 
     result_df: DataFrame = mapper.transform(df=df)
